(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;
return plural;
},
  "language": "uk",
  "x-generator": "Weblate 3.9.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Ви справді хочете вилучити цей образ?"
 ],
 "Author": [
  null,
  "Автор"
 ],
 "Automatically start podman on boot": [
  null,
  "Автоматично запускати podman під час завантаження"
 ],
 "CPU": [
  null,
  "Процесор"
 ],
 "CPU Shares": [
  null,
  "Спільне використання процесора"
 ],
 "Cancel": [
  null,
  "Скасувати"
 ],
 "Command": [
  null,
  "Команда"
 ],
 "Commit": [
  null,
  "Надіслати"
 ],
 "Commit Image": [
  null,
  "Надіслати образ"
 ],
 "Console": [
  null,
  "Консоль"
 ],
 "Container Name": [
  null,
  "Назва контейнера"
 ],
 "Container failed to be created": [
  null,
  "Не вдалося створити контейнер"
 ],
 "Container is currently running.": [
  null,
  "Контейнер працює."
 ],
 "Container is not running": [
  null,
  "Контейнер не запущено"
 ],
 "Container path": [
  null,
  "Шлях до контейнера"
 ],
 "Container port": [
  null,
  "Порт контейнера"
 ],
 "Containers": [
  null,
  "Контейнери"
 ],
 "Could not attach to this container: $0": [
  null,
  "Не вдалося долучитися до цього контейнера: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Не вдалося відкрити канал: $0"
 ],
 "Created": [
  null,
  "Створено"
 ],
 "Delete": [
  null,
  "Вилучити"
 ],
 "Delete $0": [
  null,
  "Вилучити $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Вилучення контейнера призведе до витирання усіх даних, що на ньому зберігаються."
 ],
 "Details": [
  null,
  "Подробиці"
 ],
 "Download": [
  null,
  "Отримати"
 ],
 "Download as:": [
  null,
  "Отримати як:"
 ],
 "Entrypoint": [
  null,
  "Точка входження"
 ],
 "Environment": [
  null,
  "Середовище"
 ],
 "Error message": [
  null,
  "Повідомлення про помилку"
 ],
 "Everything": [
  null,
  "Все"
 ],
 "Exited": [
  null,
  "Вийшов"
 ],
 "Failed to commit container $0": [
  null,
  "Не вдалося надіслати на обробку контейнер $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Не вдалося отримати образ $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Не вдалося примусово вилучити контейнер $0"
 ],
 "Failed to remove container $0": [
  null,
  "Не вдалося вилучити контейнер $0"
 ],
 "Failed to restart container $0": [
  null,
  "Не вдалося перезапустити контейнер $0"
 ],
 "Failed to search for new images": [
  null,
  "Не вдалося виконати пошук нових образів"
 ],
 "Failed to start container $0": [
  null,
  "Не вдалося запустити роботу контейнера $0"
 ],
 "Failed to stop container $0": [
  null,
  "Не вдалося зупинити роботу контейнера $0"
 ],
 "Force Delete": [
  null,
  "Примусове вилучення"
 ],
 "Force Restart": [
  null,
  "Примусовий перезапуск"
 ],
 "Force Stop": [
  null,
  "Примусово зупинити"
 ],
 "Format": [
  null,
  "Формат"
 ],
 "Get new image": [
  null,
  "Отримати новий образ"
 ],
 "GiB": [
  null,
  "ГіБ"
 ],
 "Host path": [
  null,
  "Шлях у основній системі"
 ],
 "Host port": [
  null,
  "Порт основної системи"
 ],
 "ID": [
  null,
  "Ід."
 ],
 "Image": [
  null,
  "Зображення"
 ],
 "Image Name": [
  null,
  "Назви предметів"
 ],
 "Images": [
  null,
  "Зображення"
 ],
 "Images and running containers": [
  null,
  "Образи і запущені контейнери"
 ],
 "Key": [
  null,
  "Ключ"
 ],
 "KiB": [
  null,
  "КіБ"
 ],
 "Loading...": [
  null,
  "Завантаження…"
 ],
 "Memory": [
  null,
  "Пам'ять"
 ],
 "Memory Limit": [
  null,
  "Обмеження пам’яті"
 ],
 "Message": [
  null,
  "Повідомлення"
 ],
 "MiB": [
  null,
  "МіБ"
 ],
 "Name": [
  null,
  "Назва"
 ],
 "No containers": [
  null,
  "Немає контейнерів"
 ],
 "No containers are using this image": [
  null,
  "Цей образ не використовує жоден контейнер"
 ],
 "No containers that match the current filter": [
  null,
  "Немає контейнерів, які проходять поточні умови фільтрування"
 ],
 "No images": [
  null,
  "Немає образів"
 ],
 "No images that match the current filter": [
  null,
  "Немає образів, які проходять поточні умови фільтрування"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "Нічого не знайдено для $0. Будь ласка, повторіть спробу із іншим ключем пошуку."
 ],
 "No running containers": [
  null,
  "Немає запущених контейнерів"
 ],
 "On Build": [
  null,
  "При збиранні"
 ],
 "Owner": [
  null,
  "Власник"
 ],
 "Pause": [
  null,
  "Призупинити"
 ],
 "Pause the container": [
  null,
  "Призупинити роботу контейнера"
 ],
 "Please confirm deletion of $0": [
  null,
  "Будь ласка, підтвердьте вилучення $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Будь ласка, підтвердьте примусове вилучення $0"
 ],
 "Podman Containers": [
  null,
  "Контейнери Podman"
 ],
 "Podman Service is Not Active": [
  null,
  "Служба Podman є неактивною"
 ],
 "Ports": [
  null,
  "Порти"
 ],
 "Pulling": [
  null,
  "Отримання даних"
 ],
 "ReadOnly": [
  null,
  "Лише читання"
 ],
 "ReadWrite": [
  null,
  "Запис-читання"
 ],
 "Restart": [
  null,
  "Перезапустити"
 ],
 "Run": [
  null,
  "Запустити"
 ],
 "Run Image": [
  null,
  "Запустити образ"
 ],
 "Search Image": [
  null,
  "Шукати образ"
 ],
 "Search by name or description": [
  null,
  "Шукати за назвою і описом"
 ],
 "Security": [
  null,
  "Безпека"
 ],
 "Set container on build variables": [
  null,
  "Встановити змінні збирання контейнера"
 ],
 "Size": [
  null,
  "Розмір"
 ],
 "Start": [
  null,
  "Запустити"
 ],
 "Start podman": [
  null,
  "Запустити podman"
 ],
 "State": [
  null,
  "Стан"
 ],
 "Stop": [
  null,
  "Зупинити"
 ],
 "System": [
  null,
  "Система"
 ],
 "System Podman service is also available": [
  null,
  "Також доступна загальносистемна служба Podman"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Мітка"
 ],
 "Tags": [
  null,
  "Мітки"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "Скануванням від $time ($type) вразливостей не знайдено."
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "У цій версії Web Console не передбачено підтримки терміналів."
 ],
 "Troubleshoot": [
  null,
  "Діагностика проблем"
 ],
 "Type to filter…": [
  null,
  "Введіть щось для фільтрування…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Працює з $0"
 ],
 "Used By": [
  null,
  "Використовується"
 ],
 "User Podman service is also available": [
  null,
  "Також доступна служба користувачів Podman"
 ],
 "Value": [
  null,
  "Значення"
 ],
 "Volumes": [
  null,
  "Томи"
 ],
 "With terminal": [
  null,
  "За допомогою термінала"
 ],
 "n/a": [
  null,
  "н/д"
 ],
 "not available": [
  null,
  "не доступне"
 ],
 "system": [
  null,
  "система"
 ],
 "user": [
  null,
  "користувач"
 ]
}));
