(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "pt_PT",
  "x-generator": "Weblate 4.0.3"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Tem a certeza que deseja eliminar esta imagem?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  ""
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "Partilhas de CPU"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Implementar"
 ],
 "Commit Image": [
  null,
  "Implementar imagem"
 ],
 "Console": [
  null,
  "Consola"
 ],
 "Container Name": [
  null,
  "Nome do 'Container'"
 ],
 "Container failed to be created": [
  null,
  "Não foi possível criar 'Container'"
 ],
 "Container is currently running.": [
  null,
  "'Container' está em execução."
 ],
 "Container is not running": [
  null,
  "'Container' não está em execução."
 ],
 "Container path": [
  null,
  "Caminho do 'Container'"
 ],
 "Container port": [
  null,
  "Porta do 'Container'"
 ],
 "Containers": [
  null,
  "'Containers'"
 ],
 "Could not attach to this container: $0": [
  null,
  "Não foi possível anexar este 'Container': $0"
 ],
 "Could not open channel: $0": [
  null,
  "Não foi possível abrir o canal: $0"
 ],
 "Created": [
  null,
  "Criado"
 ],
 "Delete": [
  null,
  "Eliminar"
 ],
 "Delete $0": [
  null,
  "Eliminar $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Ao eliminar um 'Container' irá apagar todos os dados no mesmo."
 ],
 "Details": [
  null,
  "Detalhes"
 ],
 "Download": [
  null,
  "Transferir"
 ],
 "Download as:": [
  null,
  "Transferir como:"
 ],
 "Entrypoint": [
  null,
  ""
 ],
 "Environment": [
  null,
  "Ambiente"
 ],
 "Error message": [
  null,
  "Mensagem de erro"
 ],
 "Everything": [
  null,
  "Tudo"
 ],
 "Exited": [
  null,
  ""
 ],
 "Failed to commit container $0": [
  null,
  "Não foi possível implementar ''container'' $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Não foi possível transferir a imagem $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Não foi possível forçar a remoção do 'container' $"
 ],
 "Failed to remove container $0": [
  null,
  "Não foi possível remover o 'container' $0"
 ],
 "Failed to restart container $0": [
  null,
  "Não foi possível reiniciar o 'container' $0"
 ],
 "Failed to search for new images": [
  null,
  "Não foi possível procurar por novas imagens"
 ],
 "Failed to start container $0": [
  null,
  "Não foi possível iniciar o \"container\" $0"
 ],
 "Failed to stop container $0": [
  null,
  "Não foi possível para o 'container' $0"
 ],
 "Force Delete": [
  null,
  "Forçar Eliminar"
 ],
 "Force Restart": [
  null,
  "Forçar Reiniciar"
 ],
 "Force Stop": [
  null,
  "Forçar Parar"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Get new image": [
  null,
  "Obter nova imagem"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Caminho do anfitrião"
 ],
 "Host port": [
  null,
  "Porta do anfitrião"
 ],
 "ID": [
  null,
  "Id."
 ],
 "Image": [
  null,
  "Imagem"
 ],
 "Image Name": [
  null,
  "Nome da Imagem"
 ],
 "Images": [
  null,
  "Imagens"
 ],
 "Images and running containers": [
  null,
  ""
 ],
 "Key": [
  null,
  ""
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "A carregar..."
 ],
 "Memory": [
  null,
  "Memória"
 ],
 "Memory Limit": [
  null,
  "Limite de Memória"
 ],
 "Message": [
  null,
  "Mensagem"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Nome"
 ],
 "No containers": [
  null,
  ""
 ],
 "No containers are using this image": [
  null,
  ""
 ],
 "No containers that match the current filter": [
  null,
  ""
 ],
 "No images": [
  null,
  ""
 ],
 "No images that match the current filter": [
  null,
  ""
 ],
 "No results for $0. Please retry another term.": [
  null,
  ""
 ],
 "No running containers": [
  null,
  ""
 ],
 "On Build": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Dono"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  ""
 ],
 "Please confirm deletion of $0": [
  null,
  ""
 ],
 "Please confirm forced deletion of $0": [
  null,
  ""
 ],
 "Podman Containers": [
  null,
  ""
 ],
 "Podman Service is Not Active": [
  null,
  ""
 ],
 "Ports": [
  null,
  "Portas"
 ],
 "Pulling": [
  null,
  ""
 ],
 "ReadOnly": [
  null,
  "Só de leitura"
 ],
 "ReadWrite": [
  null,
  "Ler Gravar"
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Run": [
  null,
  "Executar"
 ],
 "Run Image": [
  null,
  "Executar Imagem"
 ],
 "Search Image": [
  null,
  "Procurar Imagem"
 ],
 "Search by name or description": [
  null,
  "Procurar por nome ou descrição"
 ],
 "Security": [
  null,
  "Segurança"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Size": [
  null,
  "Tamanho"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  ""
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  ""
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  ""
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  ""
 ],
 "Troubleshoot": [
  null,
  "Resolução de problemas"
 ],
 "Type to filter…": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  ""
 ],
 "Used By": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  ""
 ],
 "Value": [
  null,
  "Valor"
 ],
 "Volumes": [
  null,
  "Volumes"
 ],
 "With terminal": [
  null,
  "Com terminal"
 ],
 "n/a": [
  null,
  "n/d"
 ],
 "not available": [
  null,
  "indisponível"
 ],
 "system": [
  null,
  "sistema"
 ],
 "user": [
  null,
  "utilizador"
 ]
}));
