(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "cs",
  "x-generator": "Weblate 3.10.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Opravdu chcete tento obraz smazat?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman spouštět automaticky při zavádění systému"
 ],
 "CPU": [
  null,
  "Procesor"
 ],
 "CPU Shares": [
  null,
  "Sdílení procesoru"
 ],
 "Cancel": [
  null,
  "Storno"
 ],
 "Command": [
  null,
  "Příkaz"
 ],
 "Commit": [
  null,
  "Odeslat"
 ],
 "Commit Image": [
  null,
  "Odeslat obraz"
 ],
 "Console": [
  null,
  "Konzole"
 ],
 "Container Name": [
  null,
  "Název kontejneru"
 ],
 "Container failed to be created": [
  null,
  "Kontejner se nepodařilo vytvořit"
 ],
 "Container is currently running.": [
  null,
  "Kontejner je nyní spuštěný."
 ],
 "Container is not running": [
  null,
  "Kontejner není spuštěný"
 ],
 "Container path": [
  null,
  "Popis umístění kontejneru"
 ],
 "Container port": [
  null,
  "Port kontejneru"
 ],
 "Containers": [
  null,
  "Kontejnery"
 ],
 "Could not attach to this container: $0": [
  null,
  "Nedaří se připojit k tomuto kontejneru: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Nedaří se otevřít kanál:$0"
 ],
 "Created": [
  null,
  "Vytvořeno"
 ],
 "Delete": [
  null,
  "Smazat"
 ],
 "Delete $0": [
  null,
  "Smazat $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Smazání kontejneru smaže veškerá data v něm."
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Download": [
  null,
  "Stáhnout"
 ],
 "Download as:": [
  null,
  "Stáhnout jako:"
 ],
 "Entrypoint": [
  null,
  "Vstupní bod"
 ],
 "Environment": [
  null,
  "Prostředí"
 ],
 "Error message": [
  null,
  "Chybové hlášení"
 ],
 "Everything": [
  null,
  "Vše"
 ],
 "Exited": [
  null,
  "Skončilo"
 ],
 "Failed to commit container $0": [
  null,
  "Nepodařilo se odeslat kontejner $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Nepodařilo se stáhnout obraz $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Nepodařilo se vynutit odebrání kontejneru $0"
 ],
 "Failed to remove container $0": [
  null,
  "Nepodařilo se odebrat kontejner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Nepodařilo se restartovat kontejner $0"
 ],
 "Failed to search for new images": [
  null,
  "Nepodařilo se vyhledat nové obrazy"
 ],
 "Failed to start container $0": [
  null,
  "Nepodařilo se spustit kontejner $0"
 ],
 "Failed to stop container $0": [
  null,
  "Nepodařilo se spustit kontejner $0"
 ],
 "Force Delete": [
  null,
  "Vynutit smazání"
 ],
 "Force Restart": [
  null,
  "Vynutit restart"
 ],
 "Force Stop": [
  null,
  "Vynutit zastavení"
 ],
 "Format": [
  null,
  "Formát"
 ],
 "Get new image": [
  null,
  "Získat nový obraz"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Popis umístění hostitele"
 ],
 "Host port": [
  null,
  "Port hostitele"
 ],
 "ID": [
  null,
  "Identif."
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image Name": [
  null,
  "Název obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Images and running containers": [
  null,
  "Obrazy a spuštěné kontejnery"
 ],
 "Key": [
  null,
  "Klíč"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "Načítání…"
 ],
 "Memory": [
  null,
  "Operační paměť"
 ],
 "Memory Limit": [
  null,
  "Limit operační paměti"
 ],
 "Message": [
  null,
  "Zpráva"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Název"
 ],
 "No containers": [
  null,
  "Žádné kontejnery"
 ],
 "No containers are using this image": [
  null,
  "Tento obraz není používán žádným kontejnerem"
 ],
 "No containers that match the current filter": [
  null,
  "Stávajícímu filtru neodpovídají žádné kontejnery"
 ],
 "No images": [
  null,
  "Žádné obrazy"
 ],
 "No images that match the current filter": [
  null,
  "Žádné obrazy které by odpovídaly stávajícímu filtru"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "Žádné výsledky vyhledání $0. Zkuste jiný pojem."
 ],
 "No running containers": [
  null,
  "Žádné spuštěné kontejnery"
 ],
 "On Build": [
  null,
  "Při sestavení"
 ],
 "Owner": [
  null,
  "Vlastník"
 ],
 "Pause": [
  null,
  "Pozastavit"
 ],
 "Pause the container": [
  null,
  "Pozastavit kontejner"
 ],
 "Please confirm deletion of $0": [
  null,
  "Potvrďte smazání $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Potvrďte vynucení smazání $0"
 ],
 "Podman Containers": [
  null,
  "Podman kontejnery"
 ],
 "Podman Service is Not Active": [
  null,
  "Služba podman není aktivní"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Pulling": [
  null,
  "Stahování"
 ],
 "ReadOnly": [
  null,
  "PouzeProČtení"
 ],
 "ReadWrite": [
  null,
  "ČetníZápis"
 ],
 "Restart": [
  null,
  "Restart"
 ],
 "Run": [
  null,
  "Spustit"
 ],
 "Run Image": [
  null,
  "Spustit obraz"
 ],
 "Search Image": [
  null,
  "Hledat obraz"
 ],
 "Search by name or description": [
  null,
  "Hledat název nebo popis"
 ],
 "Security": [
  null,
  "Zabezpečení"
 ],
 "Set container on build variables": [
  null,
  "Nastavit kontejner na proměnných prostředí"
 ],
 "Size": [
  null,
  "Velikost"
 ],
 "Start": [
  null,
  "Spustit"
 ],
 "Start podman": [
  null,
  "Spustit podman"
 ],
 "State": [
  null,
  "Stav"
 ],
 "Stop": [
  null,
  "Zastavit"
 ],
 "System": [
  null,
  "Systém"
 ],
 "System Podman service is also available": [
  null,
  "Systémová služba Podman je k dispozici také"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Štítek"
 ],
 "Tags": [
  null,
  "Štítky"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "Sken z $time ($type) nenalezl žádné zranitelnosti."
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Tato verze Web Console nepodporuje terminál."
 ],
 "Troubleshoot": [
  null,
  "Řešení problémů"
 ],
 "Type to filter…": [
  null,
  "Filtrujte psaním…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "V chodu od $0"
 ],
 "Used By": [
  null,
  "Používáno"
 ],
 "User Podman service is also available": [
  null,
  "Uživatelská služba Podman je také k dispozici"
 ],
 "Value": [
  null,
  "Hodnota"
 ],
 "Volumes": [
  null,
  "Svazky"
 ],
 "With terminal": [
  null,
  "S terminálem"
 ],
 "n/a": [
  null,
  "n/a"
 ],
 "not available": [
  null,
  "není k dispozici"
 ],
 "system": [
  null,
  "systém"
 ],
 "user": [
  null,
  "uživatel"
 ]
}));
