(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
return plural;
},
  "language": "sk",
  "x-generator": "Weblate 3.11.3"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Ste si istý/istá, že chcete odstrániť tento obraz?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Spúšťať podman pri zavádzaní systému"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "CPU podiely"
 ],
 "Cancel": [
  null,
  "Zrušiť"
 ],
 "Command": [
  null,
  "Príkaz"
 ],
 "Commit": [
  null,
  "Vytvoriť"
 ],
 "Commit Image": [
  null,
  "Vytvoriť obraz"
 ],
 "Console": [
  null,
  "Konzola"
 ],
 "Container Name": [
  null,
  "Názov kontajneru"
 ],
 "Container failed to be created": [
  null,
  "Kontajner sa nepodarilo vytvoriť"
 ],
 "Container is currently running.": [
  null,
  "Kontajner momentálne beží."
 ],
 "Container is not running": [
  null,
  "Kontajner nebeží"
 ],
 "Container path": [
  null,
  "Cesta v kontajneri"
 ],
 "Container port": [
  null,
  "Port kontajneru"
 ],
 "Containers": [
  null,
  "Kontajnery"
 ],
 "Could not attach to this container: $0": [
  null,
  "Nepodarilo sa pripojiť k tomuto kontajneru: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Nepodarilo sa otvoriť kanál: $0"
 ],
 "Created": [
  null,
  "Vytvorený"
 ],
 "Delete": [
  null,
  "Odstrániť"
 ],
 "Delete $0": [
  null,
  "Odstrániť $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Zmazaním kontajneru sa zmažú všetky dáta v ňom."
 ],
 "Details": [
  null,
  "Podrobnosti"
 ],
 "Download": [
  null,
  "Stiahnuť"
 ],
 "Download as:": [
  null,
  "Stiahnuť ako:"
 ],
 "Entrypoint": [
  null,
  "Vstupný bod"
 ],
 "Environment": [
  null,
  "Prostredie"
 ],
 "Error message": [
  null,
  "Chybová správa"
 ],
 "Everything": [
  null,
  "Všetko"
 ],
 "Exited": [
  null,
  "Skončený"
 ],
 "Failed to commit container $0": [
  null,
  ""
 ],
 "Failed to download image $0:$1": [
  null,
  "Nepodarilo sa stiahnuť obraz $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Nepodarilo sa vynútiť zmazanie kontajneru $0"
 ],
 "Failed to remove container $0": [
  null,
  "Nepodarilo sa zmazať kontajner $0"
 ],
 "Failed to restart container $0": [
  null,
  "Nepodarilo sa reštartovať kontajner $0"
 ],
 "Failed to search for new images": [
  null,
  "Nepodarilo sa nájsť nové obrazy"
 ],
 "Failed to start container $0": [
  null,
  "Nepodarilo sa spustiť kontajner $0"
 ],
 "Failed to stop container $0": [
  null,
  "Nepodarilo sa zastaviť kontajner $0"
 ],
 "Force Delete": [
  null,
  "Vynútiť odstránenie"
 ],
 "Force Restart": [
  null,
  "Vynútiť reštartovanie"
 ],
 "Force Stop": [
  null,
  "Vynútiť zastavenie"
 ],
 "Format": [
  null,
  "Formát"
 ],
 "Get new image": [
  null,
  "Získať nové obrazy"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Cesta na hostiteľovi"
 ],
 "Host port": [
  null,
  "Port na hostiteľovi"
 ],
 "ID": [
  null,
  "ID"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image Name": [
  null,
  "Názov obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Images and running containers": [
  null,
  "Obrazy a bežiace kontajnery"
 ],
 "Key": [
  null,
  "Kľúč"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "Načítanie..."
 ],
 "Memory": [
  null,
  "Pamäť"
 ],
 "Memory Limit": [
  null,
  "Pamäťový limit"
 ],
 "Message": [
  null,
  "Správa"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Názov"
 ],
 "No containers": [
  null,
  "Žiadne kontajnery"
 ],
 "No containers are using this image": [
  null,
  "Tento obraz nepoužívajú žiadne kontajnery"
 ],
 "No containers that match the current filter": [
  null,
  ""
 ],
 "No images": [
  null,
  "Žiadne obrazy"
 ],
 "No images that match the current filter": [
  null,
  ""
 ],
 "No results for $0. Please retry another term.": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Žiadne spustené kontajnery"
 ],
 "On Build": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Vlastník"
 ],
 "Pause": [
  null,
  "Pozastaviť"
 ],
 "Pause the container": [
  null,
  "Pozastaviť kontajner"
 ],
 "Please confirm deletion of $0": [
  null,
  ""
 ],
 "Please confirm forced deletion of $0": [
  null,
  ""
 ],
 "Podman Containers": [
  null,
  "Podman kontajnery"
 ],
 "Podman Service is Not Active": [
  null,
  "Služba Podman nie je aktívna"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Pulling": [
  null,
  ""
 ],
 "ReadOnly": [
  null,
  ""
 ],
 "ReadWrite": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Reštartovať"
 ],
 "Run": [
  null,
  "Spustiť"
 ],
 "Run Image": [
  null,
  "Spustiť obraz"
 ],
 "Search Image": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  ""
 ],
 "Security": [
  null,
  "Bezpečnosť"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Size": [
  null,
  "Veľkosť"
 ],
 "Start": [
  null,
  "Spustiť"
 ],
 "Start podman": [
  null,
  "Spustiť podman"
 ],
 "State": [
  null,
  "Stav"
 ],
 "Stop": [
  null,
  "Zastaviť"
 ],
 "System": [
  null,
  "Systém"
 ],
 "System Podman service is also available": [
  null,
  "Systémový podman je tiež dostupný"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tag"
 ],
 "Tags": [
  null,
  "Tagy"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  ""
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  ""
 ],
 "Troubleshoot": [
  null,
  "Riešiť problém"
 ],
 "Type to filter…": [
  null,
  ""
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Aktívny od $0"
 ],
 "Used By": [
  null,
  "Využívaný s"
 ],
 "User Podman service is also available": [
  null,
  "Užívateľský podman je tiež dostupný"
 ],
 "Value": [
  null,
  "Hodnota"
 ],
 "Volumes": [
  null,
  "Zväzky"
 ],
 "With terminal": [
  null,
  "S terminálom"
 ],
 "n/a": [
  null,
  "Nedostupné"
 ],
 "not available": [
  null,
  "nedostupné"
 ],
 "system": [
  null,
  "systém"
 ],
 "user": [
  null,
  "používateľ"
 ]
}));
