(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 3.10.3"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Voulez-vous vraiment supprimer cette image ?"
 ],
 "Author": [
  null,
  "Auteur"
 ],
 "Automatically start podman on boot": [
  null,
  "Démarrer automatiquement podman au démarrage"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "Parts de CPU"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Command": [
  null,
  "Commande"
 ],
 "Commit": [
  null,
  "Valider"
 ],
 "Commit Image": [
  null,
  "Valider image"
 ],
 "Console": [
  null,
  "Console"
 ],
 "Container Name": [
  null,
  "Nom du conteneur"
 ],
 "Container failed to be created": [
  null,
  "Le conteneur n’a pas pu être créé"
 ],
 "Container is currently running.": [
  null,
  "Le conteneur est actuellement en cours d’exécution."
 ],
 "Container is not running": [
  null,
  "Le conteneur n’est pas en cours d’exécution"
 ],
 "Container path": [
  null,
  "Chemin du conteneur"
 ],
 "Container port": [
  null,
  "Port du conteneur"
 ],
 "Containers": [
  null,
  "Conteneurs"
 ],
 "Could not attach to this container: $0": [
  null,
  "Impossible de s’attacher à ce conteneur : $0"
 ],
 "Could not open channel: $0": [
  null,
  "Impossible d’ouvrir le canal : $0"
 ],
 "Created": [
  null,
  "Créé"
 ],
 "Delete": [
  null,
  "Supprimer"
 ],
 "Delete $0": [
  null,
  "Supprimer $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Supprimer un conteneur va effacer toutes les données qu’il contient."
 ],
 "Details": [
  null,
  "Détails"
 ],
 "Download": [
  null,
  "Télécharger"
 ],
 "Download as:": [
  null,
  "Télécharger en tant que :"
 ],
 "Entrypoint": [
  null,
  "Point d’entrée"
 ],
 "Environment": [
  null,
  "Environnement"
 ],
 "Error message": [
  null,
  "Message d’erreur"
 ],
 "Everything": [
  null,
  "Tout"
 ],
 "Exited": [
  null,
  "Quittés"
 ],
 "Failed to commit container $0": [
  null,
  "Échec de la validation du conteneur $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Échec du téléchargement de l’image $0 : $1"
 ],
 "Failed to force remove container $0": [
  null,
  "Échec de la suppression forcée du conteneur $0"
 ],
 "Failed to remove container $0": [
  null,
  "Échec de la suppression du conteneur $0"
 ],
 "Failed to restart container $0": [
  null,
  "Échec du redémarrage du conteneur $0"
 ],
 "Failed to search for new images": [
  null,
  "Échec de la recherche de nouvelles images"
 ],
 "Failed to start container $0": [
  null,
  "Échec du démarrage du conteneur $0"
 ],
 "Failed to stop container $0": [
  null,
  "Échec de l’arrêt du conteneur $0"
 ],
 "Force Delete": [
  null,
  "Suppression forcée"
 ],
 "Force Restart": [
  null,
  "Redémarrage forcé"
 ],
 "Force Stop": [
  null,
  "Arrêt forcé"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Get new image": [
  null,
  "Obtenir une nouvelle image"
 ],
 "GiB": [
  null,
  "Gio"
 ],
 "Host path": [
  null,
  "Chemin vers l’hôte"
 ],
 "Host port": [
  null,
  "Port de l’hôte"
 ],
 "ID": [
  null,
  "ID"
 ],
 "Image": [
  null,
  "Image"
 ],
 "Image Name": [
  null,
  "Nom de l’image"
 ],
 "Images": [
  null,
  "Images"
 ],
 "Images and running containers": [
  null,
  "Images et conteneurs en cours d’exécution"
 ],
 "Key": [
  null,
  "Clé"
 ],
 "KiB": [
  null,
  "Kio"
 ],
 "Loading...": [
  null,
  "Chargement…"
 ],
 "Memory": [
  null,
  "Mémoire"
 ],
 "Memory Limit": [
  null,
  "Limite mémoire"
 ],
 "Message": [
  null,
  "Message"
 ],
 "MiB": [
  null,
  "Mio"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "No containers": [
  null,
  "Aucun conteneur"
 ],
 "No containers are using this image": [
  null,
  "Aucun conteneur n’utilise cette image"
 ],
 "No containers that match the current filter": [
  null,
  "Aucun conteneur ne correspond au filtre actuel"
 ],
 "No images": [
  null,
  "Aucune image"
 ],
 "No images that match the current filter": [
  null,
  "Aucune image ne correspond au filtre actuel"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "Aucun résultat pour $0. Veuillez essayer avec un autre terme."
 ],
 "No running containers": [
  null,
  "Aucun conteneur en cours d’exécution"
 ],
 "On Build": [
  null,
  "En construction"
 ],
 "Owner": [
  null,
  "Propriétaire"
 ],
 "Pause": [
  null,
  "Pause"
 ],
 "Pause the container": [
  null,
  "Mettre le conteneur en pause"
 ],
 "Please confirm deletion of $0": [
  null,
  "Veuillez confirmer la suppression de $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Veuillez confirmer la suppression forcée de $0"
 ],
 "Podman Containers": [
  null,
  "Conteneurs Podman"
 ],
 "Podman Service is Not Active": [
  null,
  "Le service Podman n’est pas actif"
 ],
 "Ports": [
  null,
  "Ports"
 ],
 "Pulling": [
  null,
  "Tirage"
 ],
 "ReadOnly": [
  null,
  "LectureSeule"
 ],
 "ReadWrite": [
  null,
  "LectureÉcriture"
 ],
 "Restart": [
  null,
  "Redémarrer"
 ],
 "Run": [
  null,
  "Exécuter"
 ],
 "Run Image": [
  null,
  "Exécuter image"
 ],
 "Search Image": [
  null,
  "Chercher image"
 ],
 "Search by name or description": [
  null,
  "Rechercher par nom ou description"
 ],
 "Security": [
  null,
  "Sécurité"
 ],
 "Set container on build variables": [
  null,
  "Définir le conteneur sur les variables de construction"
 ],
 "Size": [
  null,
  "Taille"
 ],
 "Start": [
  null,
  "Démarrer"
 ],
 "Start podman": [
  null,
  "Démarrer podman"
 ],
 "State": [
  null,
  "État"
 ],
 "Stop": [
  null,
  "Arrêter"
 ],
 "System": [
  null,
  "Système"
 ],
 "System Podman service is also available": [
  null,
  "Le service Podman est également disponible"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Tag"
 ],
 "Tags": [
  null,
  "Étiquettes"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "L’analyse de $time ($type) n’a trouvé aucune vulnérabilité."
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Cette version de la console web n’est compatible avec les terminaux."
 ],
 "Troubleshoot": [
  null,
  "Dépannage"
 ],
 "Type to filter…": [
  null,
  "Entrez pour filtrer…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "En cours d’exécution depuis $0"
 ],
 "Used By": [
  null,
  "Utilisé par"
 ],
 "User Podman service is also available": [
  null,
  "Le service utilisateur Podman est également disponible"
 ],
 "Value": [
  null,
  "Valeur"
 ],
 "Volumes": [
  null,
  "Volumes"
 ],
 "With terminal": [
  null,
  "Avec le terminal"
 ],
 "n/a": [
  null,
  "n. d."
 ],
 "not available": [
  null,
  "non disponible"
 ],
 "system": [
  null,
  "système"
 ],
 "user": [
  null,
  "utilisateur"
 ]
}));
