.podman-search .modal-content {
    display: grid;
    height: calc(100vh - 1.5rem);
    grid-template-rows: auto 1fr auto;
}

@media (min-width: 768px) {
    .podman-search .modal-content {
        height: calc(100vh - 5rem);
    }
}

.podman-search h5 {
    font-size: var(--pf-global--FontSize--xl);
    margin: 2rem 0 1rem;
}

@media (max-width: 767px) {
    /* Conserve vertical space on phones */
    .podman-search h5 {
        display: none;
    }
}

.podman-search .modal-body {
    display: flex;
    flex-direction: column;
    overflow: hidden;
}

.podman-search .list-group {
    overflow: hidden scroll;
    flex: auto;
    margin: 0;
    border: 1px solid var(--pf-global--BorderColor--100);
}

.input-group > .input-group-addon {
    align-items: center;
}

#search-image-dialog-waiting.spinner {
    margin-top: calc(50% - 32px);
}

.image-list-item {
    display: grid;
    grid-gap: 0 1rem;
}

.image-list-item + .image-list-item {
    border-top: 1px solid var(--pf-global--BorderColor--200);
}

@media (min-width: 768px) {
    .image-list-item {
        grid-template-columns: 1fr 2fr;
    }
}

.image-list-item > .control-label {
    margin: 0;
}

@media (max-width: 767px) {
    .image-list-item {
        font-size: var(--pf-global--FontSize--sm);
    }
    .image-list-item > .control-label {
        font-size: var(--pf-global--FontSize--md);
    }
}

.list-group .list-group-item:focus,
.list-group .list-group-item:active,
.list-group .list-group-item:hover {
    background-color: var(--pf-global--BackgroundColor--light-300);
    border-color: var(--pf-global--BackgroundColor--light-300);
}

.list-group .list-group-item.active {
    background-color: var(--pf-global--active-color--200);
    border-color: var(--pf-global--active-color--200);
    color: var(--pf-global--Color--100);
}

.podman-search .modal-footer::before,
.podman-search .modal-footer::after {
    display: none;
}

.podman-search .image-search-modal-footer-grid {
    display: grid;
    grid-template-columns: 1fr auto auto;
    grid-gap: 0.25rem;
}

.podman-search .modal-footer > .btn {
    margin: 0;
}

.image-tag-entry {
    max-width: 15rem;
}

@media (max-width: 340px) {
    /* Shrink buttons to accomodate iPhone 5/SE */
    .podman-search .modal-footer > .btn {
        padding-left: 0.25rem;
        padding-right: 0.25rem;
    }
}

.ct-form .radio {
    margin-top: 0px;
    margin-bottom: 0px;
}
