(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "tr",
  "x-generator": "Weblate 4.0.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Bu kalıbı silmek istediğinizden emin misiniz?"
 ],
 "Author": [
  null,
  "Yazar"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman'ı başlangıçta otomatik olarak başlat"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "CPU Paylaşımları"
 ],
 "Cancel": [
  null,
  "İptal"
 ],
 "Command": [
  null,
  "Komut"
 ],
 "Commit": [
  null,
  "İşle"
 ],
 "Commit Image": [
  null,
  "Kalıbı İşle"
 ],
 "Console": [
  null,
  "Konsol"
 ],
 "Container Name": [
  null,
  "Konteyner Adı"
 ],
 "Container failed to be created": [
  null,
  "Konteyner oluşturulamadı"
 ],
 "Container is currently running.": [
  null,
  "Konteyner şu anda çalışıyor."
 ],
 "Container is not running": [
  null,
  "Konteyner çalışmıyor"
 ],
 "Container path": [
  null,
  "Konteyner konumu"
 ],
 "Container port": [
  null,
  "Konteyner bağlantı noktası"
 ],
 "Containers": [
  null,
  "Konteynerler"
 ],
 "Could not attach to this container: $0": [
  null,
  "Bu konteynere iliştirilemedi: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Kanal açılamadı: $0"
 ],
 "Created": [
  null,
  "Oluşturuldu"
 ],
 "Delete": [
  null,
  "Sil"
 ],
 "Delete $0": [
  null,
  "$0 sil"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Bir konteyneri silmek içindeki tüm verileri silecektir."
 ],
 "Details": [
  null,
  "Ayrıntılar"
 ],
 "Download": [
  null,
  "İndir"
 ],
 "Download as:": [
  null,
  "Farklı indir:"
 ],
 "Entrypoint": [
  null,
  "Giriş noktası"
 ],
 "Environment": [
  null,
  "Ortam"
 ],
 "Error message": [
  null,
  "Hata mesajı"
 ],
 "Everything": [
  null,
  "Her şey"
 ],
 "Exited": [
  null,
  "Çıkış yaptı"
 ],
 "Failed to commit container $0": [
  null,
  "$0 konteyneri işlenemedi"
 ],
 "Failed to download image $0:$1": [
  null,
  "$0:$1 kalıbı indirilemedi"
 ],
 "Failed to force remove container $0": [
  null,
  "$0 konteyneri zorla kaldırılamadı"
 ],
 "Failed to remove container $0": [
  null,
  "$0 konteyneri kaldırılamadı"
 ],
 "Failed to restart container $0": [
  null,
  "$0 konteyneri yeniden başlatılamadı"
 ],
 "Failed to search for new images": [
  null,
  "Yeni kalıplar aranamadı"
 ],
 "Failed to start container $0": [
  null,
  "$0 konteyneri başlatılamadı"
 ],
 "Failed to stop container $0": [
  null,
  "$0 konteyneri durdurulamadı"
 ],
 "Force Delete": [
  null,
  "Silmeye Zorla"
 ],
 "Force Restart": [
  null,
  "Yeniden Başlatmaya Zorla"
 ],
 "Force Stop": [
  null,
  "Durmaya Zorla"
 ],
 "Format": [
  null,
  "Biçim"
 ],
 "Get new image": [
  null,
  "Yeni kalıp al"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Ana makine yolu"
 ],
 "Host port": [
  null,
  "Ana makine bağlantı noktası"
 ],
 "ID": [
  null,
  "Kimlik"
 ],
 "Image": [
  null,
  "Kalıp"
 ],
 "Image Name": [
  null,
  "Kalıp Adı"
 ],
 "Images": [
  null,
  "Kalıplar"
 ],
 "Images and running containers": [
  null,
  "Kalıplar ve çalışan konteynerler"
 ],
 "Key": [
  null,
  "Anahtar"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "Yükleniyor..."
 ],
 "Memory": [
  null,
  "Bellek"
 ],
 "Memory Limit": [
  null,
  "Bellek Limiti"
 ],
 "Message": [
  null,
  "Mesaj"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "İsim"
 ],
 "No containers": [
  null,
  "Konteyner yok"
 ],
 "No containers are using this image": [
  null,
  "Bu kalıbı hiçbir konteyner kullanmıyor"
 ],
 "No containers that match the current filter": [
  null,
  "Geçerli filtreyle eşleşen konteyner yok"
 ],
 "No images": [
  null,
  "Kalıp yok"
 ],
 "No images that match the current filter": [
  null,
  "Geçerli filtreyle eşleşen kalıp yok"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "$0 için sonuç yok. Lütfen başka bir terim ile tekrar deneyin."
 ],
 "No running containers": [
  null,
  "Çalışan konteyner yok"
 ],
 "On Build": [
  null,
  "Yapım Anında"
 ],
 "Owner": [
  null,
  "Sahip"
 ],
 "Pause": [
  null,
  "Duraklat"
 ],
 "Pause the container": [
  null,
  "Konteyneri duraklat"
 ],
 "Please confirm deletion of $0": [
  null,
  "Lütfen $0 için silme işlemini onaylayın"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Lütfen $0 için zorla silme işlemini onaylayın"
 ],
 "Podman Containers": [
  null,
  "Podman Konteynerleri"
 ],
 "Podman Service is Not Active": [
  null,
  "Podman Hizmeti Etkin Değil"
 ],
 "Ports": [
  null,
  "Bağlantı Noktaları"
 ],
 "Pulling": [
  null,
  "Çekiliyor"
 ],
 "ReadOnly": [
  null,
  "SadeceOku"
 ],
 "ReadWrite": [
  null,
  "OkuYaz"
 ],
 "Restart": [
  null,
  "Yeniden başlat"
 ],
 "Run": [
  null,
  "Çalıştır"
 ],
 "Run Image": [
  null,
  "Kalıbı Çalıştır"
 ],
 "Search Image": [
  null,
  "Kalıp Ara"
 ],
 "Search by name or description": [
  null,
  "İsme veya açıklamaya göre ara"
 ],
 "Security": [
  null,
  "Güvenlik"
 ],
 "Set container on build variables": [
  null,
  "Yapım değişkenlerinde konteyneri ayarla"
 ],
 "Size": [
  null,
  "Boyut"
 ],
 "Start": [
  null,
  "Başlat"
 ],
 "Start podman": [
  null,
  "Podman'ı başlat"
 ],
 "State": [
  null,
  "Durum"
 ],
 "Stop": [
  null,
  "Durdur"
 ],
 "System": [
  null,
  "Sistem"
 ],
 "System Podman service is also available": [
  null,
  "Sistem Podman hizmeti de kullanılabilir"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiket"
 ],
 "Tags": [
  null,
  "Etiketler"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "$time ($type) taraması hiçbir güvenlik açığı bulamadı."
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Web Konsolu'nun bu sürümü bir terminali desteklememektedir."
 ],
 "Troubleshoot": [
  null,
  "Sorun Giderme"
 ],
 "Type to filter…": [
  null,
  "Filtrelemek için yazın…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "$0'dan beri aktif"
 ],
 "Used By": [
  null,
  "Kullanan"
 ],
 "User Podman service is also available": [
  null,
  "Kullanıcı Podman hizmeti de kullanılabilir"
 ],
 "Value": [
  null,
  "Değer"
 ],
 "Volumes": [
  null,
  "Bölümler"
 ],
 "With terminal": [
  null,
  "Terminal ile"
 ],
 "n/a": [
  null,
  "yok"
 ],
 "not available": [
  null,
  "kullanılabilir değil"
 ],
 "system": [
  null,
  "sistem"
 ],
 "user": [
  null,
  "kullanıcı"
 ]
}));
