@import "~xterm/css/xterm.css";

.terminal {
    /* 5px all around and on right +11 since the scrollbar is 11px wide */
    padding: 5px 16px 5px 5px;
}

.empty-state {
    padding-top: 50px;
    padding-bottom: 50px;
    text-align: center;
}

.empty-message {
    font-size: 175%;
    font-weight: 100;
}
