(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "es",
  "x-generator": "Weblate 4.0.3"
 },
 "Are you sure you want to delete this image?": [
  null,
  "¿Está seguro de que quiere eliminar esta imagen?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Iniciar podman en el arranque"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "CPU compartida"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Commit"
 ],
 "Commit Image": [
  null,
  "Commit una imagen"
 ],
 "Console": [
  null,
  "Consola"
 ],
 "Container Name": [
  null,
  "Nombre de contenedor"
 ],
 "Container failed to be created": [
  null,
  "Falló al crear el contenedor"
 ],
 "Container is currently running.": [
  null,
  "El contenedor se está ejecutando."
 ],
 "Container is not running": [
  null,
  "El contenedor no se está ejecutando"
 ],
 "Container path": [
  null,
  "Ruta del contenedor"
 ],
 "Container port": [
  null,
  "Puerto del contenedor"
 ],
 "Containers": [
  null,
  "Contenedores"
 ],
 "Could not attach to this container: $0": [
  null,
  "No se pudo asociar a este contenedor: $0"
 ],
 "Could not open channel: $0": [
  null,
  "No se pudo abrir un canal: $0"
 ],
 "Created": [
  null,
  "Creado"
 ],
 "Delete": [
  null,
  "Eliminar"
 ],
 "Delete $0": [
  null,
  "Eliminar $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Eliminando un contenedor se borrará toda la información que hay en él."
 ],
 "Details": [
  null,
  "Detalles"
 ],
 "Download": [
  null,
  "Descarga"
 ],
 "Download as:": [
  null,
  "Descarga como:"
 ],
 "Entrypoint": [
  null,
  "Punto de entrada"
 ],
 "Environment": [
  null,
  "Entorno"
 ],
 "Error message": [
  null,
  "Mensaje de error"
 ],
 "Everything": [
  null,
  "Todo"
 ],
 "Exited": [
  null,
  "Cerrado"
 ],
 "Failed to commit container $0": [
  null,
  "Falló hacer el commit en el contenedor $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Falló al descargar la imagen $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Falló al forzar el borrado del contenedor $0"
 ],
 "Failed to remove container $0": [
  null,
  "Falló al eliminar el contenedor $0"
 ],
 "Failed to restart container $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to search for new images": [
  null,
  "Falló al buscar nuevas imágenes"
 ],
 "Failed to start container $0": [
  null,
  "Falló al iniciar el contenedor $0"
 ],
 "Failed to stop container $0": [
  null,
  "Falló al parar el contenedor $0"
 ],
 "Force Delete": [
  null,
  "Forzar el borrado"
 ],
 "Force Restart": [
  null,
  "Forzar el reinicio"
 ],
 "Force Stop": [
  null,
  "Forzar la parada"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Get new image": [
  null,
  "Obtener nueva imagen"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Ruta del anfitrión"
 ],
 "Host port": [
  null,
  "Puerto del anfitrión"
 ],
 "ID": [
  null,
  "ID"
 ],
 "Image": [
  null,
  "Imagen"
 ],
 "Image Name": [
  null,
  "Nombre de la imagen"
 ],
 "Images": [
  null,
  "Imágenes"
 ],
 "Images and running containers": [
  null,
  "Imágenes y contenedores en ejecución"
 ],
 "Key": [
  null,
  "Clave"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading logs...": [
  null,
  "Cargando registros..."
 ],
 "Loading...": [
  null,
  "Cargando..."
 ],
 "Logs": [
  null,
  "Registros"
 ],
 "Memory": [
  null,
  "Memoria"
 ],
 "Memory Limit": [
  null,
  "Límite de memoria"
 ],
 "Message": [
  null,
  "Mensaje"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Nombre"
 ],
 "No containers": [
  null,
  "No hay contenedores"
 ],
 "No containers are using this image": [
  null,
  "No hay contenedores que utilicen esta imagen"
 ],
 "No containers that match the current filter": [
  null,
  "No hay contenedores relacionados con los criterios de búsqueda"
 ],
 "No images": [
  null,
  "No hay imágenes"
 ],
 "No images that match the current filter": [
  null,
  "No hay imágenes relacionadas con el criterio de búsqueda"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "No se han encontrados resultados para $0. Por favor intente con otro término."
 ],
 "No running containers": [
  null,
  "No hay contenedores ejecutándose"
 ],
 "On Build": [
  null,
  "En construcción"
 ],
 "Owner": [
  null,
  "Propietario"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  "Pausar el contenedor"
 ],
 "Please confirm deletion of $0": [
  null,
  "Por favor confirme el borrado de $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Por favor confirme forzar el borrado de $0"
 ],
 "Podman Containers": [
  null,
  "Contenedores de Podman"
 ],
 "Podman Service is Not Active": [
  null,
  "El servicio de Podman no está activo"
 ],
 "Ports": [
  null,
  "Puertos"
 ],
 "Pulling": [
  null,
  "Obteniendo"
 ],
 "ReadOnly": [
  null,
  "SoloLectura"
 ],
 "ReadWrite": [
  null,
  "LecturaEscritura"
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Run": [
  null,
  "Ejecutar"
 ],
 "Run Image": [
  null,
  "Ejecutar una imagen"
 ],
 "Search Image": [
  null,
  "Buscar una imagen"
 ],
 "Search by name or description": [
  null,
  "Buscar por nombre o descripción"
 ],
 "Set container on build variables": [
  null,
  "Establecer el contenedor en las variables de construcción"
 ],
 "Size": [
  null,
  "Tamaño"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  "Iniciar podman"
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  "El servicio del sistema Podman también está disponible"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Esta versión de consola Web no soporta un terminal."
 ],
 "Troubleshoot": [
  null,
  "Solución de errores"
 ],
 "Type to filter…": [
  null,
  "Escriba para establecer un criterio de búsqueda…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Levantado desde $0"
 ],
 "Used By": [
  null,
  "Usado por"
 ],
 "User Podman service is also available": [
  null,
  "El usuario del servicio Podman también está disponible"
 ],
 "Value": [
  null,
  "Valor"
 ],
 "Volumes": [
  null,
  "Volúmenes"
 ],
 "With terminal": [
  null,
  "Con terminal"
 ],
 "container": [
  null,
  "contenedor"
 ],
 "image": [
  null,
  "imagen"
 ],
 "n/a": [
  null,
  "sin/aplicar"
 ],
 "not available": [
  null,
  "no disponible"
 ],
 "podman": [
  null,
  "podman"
 ],
 "system": [
  null,
  "sistema"
 ],
 "user": [
  null,
  "usuario"
 ]
}));
