@import (less) "../node_modules/bootstrap-less/bootstrap/variables.less";
@import (less) "../node_modules/patternfly/dist/less/variables.less";

@metadata-color: var(--color-subtle-copy);

@listing-ct-hover: var(--color-ct-list-hover-bg);
@listing-ct-hover-icon: var(--color-ct-list-hover-icon);
@listing-ct-active: var(--color-ct-list-active-bg);
@listing-ct-padding: 0.5rem;
@listing-ct-spacing: 1rem;
@listing-ct-open: #f5f5f5;
@listing-ct-open-width: 3px;
@listing-ct-metadata: @metadata-color;
@listing-ct-warning-color: var(--color-ct-light-red-1);
@listing-ct-border: var(--color-light-gray);
@listing-ct-border-light: var(--color-gray-2);
@listing-ct-border-maybe: var(--color-light-gray-3);

@screen-lg-max: (@screen-xlg-min - 1);
@screen-xlg-min: 1600px;
@screen-xs: 480px;
@screen-xs-min: @screen-xs;
@screen-xxs-max: (@screen-xs-min - 1);
