(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=3; plural=n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;
return plural;
},
  "language": "pl",
  "x-generator": "Weblate 3.10.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Na pewno usunąć ten obraz?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Automatyczne włączanie usługi podman podczas uruchamiania"
 ],
 "CPU": [
  null,
  "Procesor"
 ],
 "CPU Shares": [
  null,
  "Udziały procesora"
 ],
 "Cancel": [
  null,
  "Anuluj"
 ],
 "Command": [
  null,
  "Polecenie"
 ],
 "Commit": [
  null,
  "Zatwierdź"
 ],
 "Commit Image": [
  null,
  "Zatwierdź obraz"
 ],
 "Console": [
  null,
  "Konsola"
 ],
 "Container Name": [
  null,
  "Nazwa kontenera"
 ],
 "Container failed to be created": [
  null,
  "Utworzenie kontenera się nie powiodło"
 ],
 "Container is currently running.": [
  null,
  "Kontener jest obecnie uruchomiony."
 ],
 "Container is not running": [
  null,
  "Kontener nie jest uruchomiony"
 ],
 "Container path": [
  null,
  "Ścieżka do kontenera"
 ],
 "Container port": [
  null,
  "Port kontenera"
 ],
 "Containers": [
  null,
  "Kontenery"
 ],
 "Could not attach to this container: $0": [
  null,
  "Nie można dołączyć do tego kontenera: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Nie można otworzyć kanału: $0"
 ],
 "Created": [
  null,
  "Utworzono"
 ],
 "Delete": [
  null,
  "Usuń"
 ],
 "Delete $0": [
  null,
  "Usuń $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Usunięcie kontenera spowoduje usunięcie wszystkich zawartych na nim danych."
 ],
 "Details": [
  null,
  "Szczegóły"
 ],
 "Download": [
  null,
  "Pobierz"
 ],
 "Download as:": [
  null,
  "Pobierz jako:"
 ],
 "Entrypoint": [
  null,
  "Punkt wejścia"
 ],
 "Environment": [
  null,
  "Środowisko"
 ],
 "Error message": [
  null,
  "Komunikat o błędzie"
 ],
 "Everything": [
  null,
  "Wszystko"
 ],
 "Exited": [
  null,
  "Zakończono"
 ],
 "Failed to commit container $0": [
  null,
  "Zatwierdzenie kontenera $0 się nie powiodło"
 ],
 "Failed to download image $0:$1": [
  null,
  "Pobranie obrazu $0:$1 się nie powiodło"
 ],
 "Failed to force remove container $0": [
  null,
  "Wymuszenie usunięcia kontenera $0 się nie powiodło"
 ],
 "Failed to remove container $0": [
  null,
  "Usunięcie kontenera $0 się nie powiodło"
 ],
 "Failed to restart container $0": [
  null,
  "Ponowne uruchomienie kontenera $0 się nie powiodło"
 ],
 "Failed to search for new images": [
  null,
  "Wyszukanie nowych obrazów się nie powiodło"
 ],
 "Failed to start container $0": [
  null,
  "Uruchomienie kontenera $0 się nie powiodło"
 ],
 "Failed to stop container $0": [
  null,
  "Zatrzymanie kontenera $0 się nie powiodło"
 ],
 "Force Delete": [
  null,
  "Wymuś usunięcie"
 ],
 "Force Restart": [
  null,
  "Wymuś ponowne uruchomienie"
 ],
 "Force Stop": [
  null,
  "Wymuś zatrzymanie"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Get new image": [
  null,
  "Pobierz nowy obraz"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "Ścieżka do gospodarza"
 ],
 "Host port": [
  null,
  "Port gospodarza"
 ],
 "ID": [
  null,
  "Identyfikator"
 ],
 "Image": [
  null,
  "Obraz"
 ],
 "Image Name": [
  null,
  "Nazwa obrazu"
 ],
 "Images": [
  null,
  "Obrazy"
 ],
 "Images and running containers": [
  null,
  "Obrazy i uruchomione kontenery"
 ],
 "Key": [
  null,
  "Klucz"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "Wczytywanie…"
 ],
 "Memory": [
  null,
  "Pamięć"
 ],
 "Memory Limit": [
  null,
  "Ograniczenie pamięci"
 ],
 "Message": [
  null,
  "Komunikat"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Nazwa"
 ],
 "No containers": [
  null,
  "Brak kontenerów"
 ],
 "No containers are using this image": [
  null,
  "Żadne kontenery nie używają tego obrazu"
 ],
 "No containers that match the current filter": [
  null,
  "Żadne kontenery nie pasują do obecnego filtru"
 ],
 "No images": [
  null,
  "Brak obrazów"
 ],
 "No images that match the current filter": [
  null,
  "Żadne obrazy nie pasują do obecnego filtru"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "Brak wyników dla zapytania „$0”. Proszę spróbować innych słów."
 ],
 "No running containers": [
  null,
  "Brak uruchomionych kontenerów"
 ],
 "On Build": [
  null,
  "Podczas budowania"
 ],
 "Owner": [
  null,
  "Właściciel"
 ],
 "Pause": [
  null,
  "Wstrzymaj"
 ],
 "Pause the container": [
  null,
  "Wstrzymaj kontener"
 ],
 "Please confirm deletion of $0": [
  null,
  "Proszę potwierdzić usunięcie $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Proszę potwierdzić wymuszenie usunięcia $0"
 ],
 "Podman Containers": [
  null,
  "Kontenery Podman"
 ],
 "Podman Service is Not Active": [
  null,
  "Usługa Podman nie jest aktywna"
 ],
 "Ports": [
  null,
  "Porty"
 ],
 "Pulling": [
  null,
  "Pobieranie"
 ],
 "ReadOnly": [
  null,
  "Tylko do odczytu"
 ],
 "ReadWrite": [
  null,
  "Odczyt i zapis"
 ],
 "Restart": [
  null,
  "Uruchom ponownie"
 ],
 "Run": [
  null,
  "Uruchom"
 ],
 "Run Image": [
  null,
  "Uruchom obraz"
 ],
 "Search Image": [
  null,
  "Znajdź obraz"
 ],
 "Search by name or description": [
  null,
  "Szukaj według nazwy lub opisu"
 ],
 "Security": [
  null,
  "Zabezpieczenia"
 ],
 "Set container on build variables": [
  null,
  "Ustaw kontener na zmiennych budowania"
 ],
 "Size": [
  null,
  "Rozmiar"
 ],
 "Start": [
  null,
  "Uruchom"
 ],
 "Start podman": [
  null,
  "Uruchom usługę podman"
 ],
 "State": [
  null,
  "Stan"
 ],
 "Stop": [
  null,
  "Zatrzymaj"
 ],
 "System": [
  null,
  "System"
 ],
 "System Podman service is also available": [
  null,
  "Dostępna jest także systemowa usługa Podman"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etykieta"
 ],
 "Tags": [
  null,
  "Etykiety"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "Wyszukiwanie z $time ($type) nie znalazło żadnych zagrożeń."
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Ta wersja konsoli internetowej nie obsługuje terminala."
 ],
 "Troubleshoot": [
  null,
  "Rozwiąż problem"
 ],
 "Type to filter…": [
  null,
  "Wyszukiwanie…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Uruchomione od $0"
 ],
 "Used By": [
  null,
  "Używane przez"
 ],
 "User Podman service is also available": [
  null,
  "Dostępna jest także usługa Podman użytkownika"
 ],
 "Value": [
  null,
  "Wartość"
 ],
 "Volumes": [
  null,
  "Woluminy"
 ],
 "With terminal": [
  null,
  "Z terminalem"
 ],
 "n/a": [
  null,
  "niedostępne"
 ],
 "not available": [
  null,
  "niedostępne"
 ],
 "system": [
  null,
  "systemowa"
 ],
 "user": [
  null,
  "użytkownika"
 ]
}));
