(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "zh_CN",
  "x-generator": "Weblate 3.9.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "您确定要删除该镜像吗？"
 ],
 "Author": [
  null,
  "作者"
 ],
 "Automatically start podman on boot": [
  null,
  "开机自动启动 podman"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  "CPU 份额"
 ],
 "Cancel": [
  null,
  "取消"
 ],
 "Command": [
  null,
  "命令"
 ],
 "Commit": [
  null,
  "提交"
 ],
 "Commit Image": [
  null,
  "提交镜像"
 ],
 "Console": [
  null,
  "控制台"
 ],
 "Container Name": [
  null,
  "容器名称"
 ],
 "Container failed to be created": [
  null,
  "容器创建失败"
 ],
 "Container is currently running.": [
  null,
  "容器正在运行。"
 ],
 "Container is not running": [
  null,
  "容器未运行"
 ],
 "Container path": [
  null,
  "容器路径"
 ],
 "Container port": [
  null,
  "容器端口"
 ],
 "Containers": [
  null,
  "容器"
 ],
 "Could not attach to this container: $0": [
  null,
  "无法附加到该容器：$0"
 ],
 "Could not open channel: $0": [
  null,
  "无法打开通道：$0"
 ],
 "Created": [
  null,
  "已创建"
 ],
 "Delete": [
  null,
  "删除"
 ],
 "Delete $0": [
  null,
  "删除 $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "删除容器会清空其中的全部数据。"
 ],
 "Details": [
  null,
  "详情"
 ],
 "Download": [
  null,
  "下载"
 ],
 "Download as:": [
  null,
  "另存为："
 ],
 "Entrypoint": [
  null,
  "入口点"
 ],
 "Environment": [
  null,
  "环境"
 ],
 "Error message": [
  null,
  "错误信息"
 ],
 "Everything": [
  null,
  "全部"
 ],
 "Exited": [
  null,
  "已退出"
 ],
 "Failed to commit container $0": [
  null,
  "提交容器 $0 失败"
 ],
 "Failed to download image $0:$1": [
  null,
  "下载镜像 $0:$1 失败"
 ],
 "Failed to force remove container $0": [
  null,
  "强制移除容器 $0 失败"
 ],
 "Failed to remove container $0": [
  null,
  "移除容器 $0 失败"
 ],
 "Failed to restart container $0": [
  null,
  "重启容器 $0 失败"
 ],
 "Failed to search for new images": [
  null,
  "搜索新镜像失败"
 ],
 "Failed to start container $0": [
  null,
  "启动容器 $0 失败"
 ],
 "Failed to stop container $0": [
  null,
  "停止容器 $0 失败"
 ],
 "Force Delete": [
  null,
  "强制删除"
 ],
 "Force Restart": [
  null,
  "强制重启"
 ],
 "Force Stop": [
  null,
  "强制停止"
 ],
 "Format": [
  null,
  "格式"
 ],
 "Get new image": [
  null,
  "获取新镜像"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  "主机路径"
 ],
 "Host port": [
  null,
  "主机端口"
 ],
 "ID": [
  null,
  "ID"
 ],
 "Image": [
  null,
  "镜像"
 ],
 "Image Name": [
  null,
  "镜像名称"
 ],
 "Images": [
  null,
  "镜像"
 ],
 "Images and running containers": [
  null,
  "镜像和正在运行的容器"
 ],
 "Key": [
  null,
  "键"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "加载中……"
 ],
 "Memory": [
  null,
  "内存"
 ],
 "Memory Limit": [
  null,
  "内存限制"
 ],
 "Message": [
  null,
  "消息"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "名称"
 ],
 "No containers": [
  null,
  "没有容器"
 ],
 "No containers are using this image": [
  null,
  "没有使用该镜像的容器"
 ],
 "No containers that match the current filter": [
  null,
  "没有符合当前筛选条件的容器"
 ],
 "No images": [
  null,
  "没有镜像"
 ],
 "No images that match the current filter": [
  null,
  "没有符合当前筛选条件的镜像"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "没有匹配 $0 的结果。请换个关键词重试。"
 ],
 "No running containers": [
  null,
  "没有正在运行的容器"
 ],
 "On Build": [
  null,
  "构建时"
 ],
 "Owner": [
  null,
  "所有者"
 ],
 "Pause": [
  null,
  "暂停"
 ],
 "Pause the container": [
  null,
  "暂停该容器"
 ],
 "Please confirm deletion of $0": [
  null,
  "请确认是否删除 $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "请确认是否强制删除 $0"
 ],
 "Podman Containers": [
  null,
  "Podman 容器"
 ],
 "Podman Service is Not Active": [
  null,
  "Podman 服务未激活"
 ],
 "Ports": [
  null,
  "端口"
 ],
 "Pulling": [
  null,
  "正在拉取"
 ],
 "ReadOnly": [
  null,
  "只读"
 ],
 "ReadWrite": [
  null,
  "读写"
 ],
 "Restart": [
  null,
  "重启"
 ],
 "Run": [
  null,
  "运行"
 ],
 "Run Image": [
  null,
  "运行镜像"
 ],
 "Search Image": [
  null,
  "搜索镜像"
 ],
 "Search by name or description": [
  null,
  "按名称或描述搜索"
 ],
 "Security": [
  null,
  "安全性"
 ],
 "Set container on build variables": [
  null,
  "设置容器构建时的变量"
 ],
 "Size": [
  null,
  "大小"
 ],
 "Start": [
  null,
  "启动"
 ],
 "Start podman": [
  null,
  "启动 podman"
 ],
 "State": [
  null,
  "状态"
 ],
 "Stop": [
  null,
  "停止"
 ],
 "System": [
  null,
  "系统"
 ],
 "System Podman service is also available": [
  null,
  "系统 Podman 服务同样可用"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "标签"
 ],
 "Tags": [
  null,
  "标签"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  "$time ($type) 发起的扫描未发现漏洞。"
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "该版本的网页控制台不支持终端。"
 ],
 "Troubleshoot": [
  null,
  "故障排除"
 ],
 "Type to filter…": [
  null,
  "输入筛选条件……"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "自 $0 开始运行"
 ],
 "Used By": [
  null,
  "使用者"
 ],
 "User Podman service is also available": [
  null,
  "用户 Podman 服务同样可用"
 ],
 "Value": [
  null,
  "值"
 ],
 "Volumes": [
  null,
  "卷"
 ],
 "With terminal": [
  null,
  "分配伪终端"
 ],
 "n/a": [
  null,
  "不适用"
 ],
 "not available": [
  null,
  "不可用"
 ],
 "system": [
  null,
  "系统"
 ],
 "user": [
  null,
  "用户"
 ]
}));
